/* === Science & Technology Consultants (SciTeX) = Fri-03-10-2006 === */

/* --- Parameters --------------------------------------------------- */

Include "Test-2D.par";

/* --- Groups ------------------------------------------------------- */

Group {
/* ... Volume ....................................................... */

  VolDsk = Region[6001]; // Disk

/* ... Surface ...................................................... */

  SfcBtm = Region[5001]; // Bottom
  SfcSde = Region[5002]; // Side
  SfcTop = Region[5003]; // Top

/* ... Domain ....................................................... */

  Sfc = Region[{SfcBtm,SfcSde,SfcTop}] ;
  Vol = Region[{VolDsk}] ;

  Dmn = Region[{Sfc,Vol}];
}

/* --- Functions ---------------------------------------------------- */

Function {
/* ... Time ......................................................... */

//  TmeFct[] = ($Time < 1.0) ? 0.0 : 1.0;

/* ... Save ......................................................... */

  SveFct[] = !($TimeStep % 1);

/* ... Volume Properties ............................................ */

  MasDen[VolDsk]    = 2330.0;
  HeaCap[VolDsk]    =  507.0;
  TheCon[VolDsk]    =  148.0;

/* ... Volume Drivers ............................................... */

  HeaPwr[VolDsk]    = 0.0;

/* ... Surface Drivers .............................................. */

  HeaFlx[SfcBtm]    = 0.0;
  HeaFlx[SfcSde]    = 0.0;
  HeaFlx[SfcTop]    = Flx * (1.0 - (X[]/Rds)^2);
//  HeaFlx[SfcTop]    = Flx * TmeFct[] * (1.0 - (X[]/Rds)^2);

/* ... Surface Convection ........................................... */

  HTCCvn[SfcBtm] = HTC;
  TmpCvn[SfcBtm] = TmpIni;

  HTCCvn[SfcSde] = HTC;
  TmpCvn[SfcSde] = TmpIni;

  HTCCvn[SfcTop] = HTC;
  TmpCvn[SfcTop] = TmpIni;

/* ... Surface Radiation ............................................ */

  HTCRdn[SfcBtm]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcBtm]   = TmpIni;

  HTCRdn[SfcSde]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcSde]   = TmpIni;

  HTCRdn[SfcTop]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcTop]   = TmpIni;
}

/* --- Constraint --------------------------------------------------- */

Constraint {
  {Name TmpCon;
    Case {
//      {Region SfcBtm; Type Assign; Value TmpIni;}
//      {Region SfcSde; Type Assign; Value TmpIni;}
//      {Region SfcTop; Type Assign; Value TmpIni;}
      {Region Dmn; Type Init; Value TmpIni;}
    }
  }
}

/* --- General Thermal Problem Solver ------------------------------- */

Include "Test-2D.sol";

/* --- Post Operation ----------------------------------------------- */

PostOperation {
  {Name Tmp3D; NameOfPostProcessing TmpPst;
    Operation {
      Print[Tmp, OnElementsOf Dmn, File "Tmp-3D.pos"];
      Print[Flx, OnElementsOf Dmn, File "Flx-3D.pos"];
      Print[Abs, OnElementsOf Dmn, File "Abs-3D.pos"];
    }
  }    
    
  {Name Tmp2D; NameOfPostProcessing TmpPst;
    Operation {
      Print[Tmp,OnLine { {0.0,0.0,0.0} {Rds,0.0,0.0} } {25}, File "Tmp-2D_Btm.pos"];
      Print[Flx,OnLine { {0.0,0.0,0.0} {Rds,0.0,0.0} } {25}, File "Flx-2D_Btm.pos"];
      Print[Tmp,OnLine { {Rds,0.0,0.0} {Rds,Hgt,0.0} } {25}, File "Tmp-2D_Sde.pos"];
      Print[Flx,OnLine { {Rds,0.0,0.0} {Rds,Hgt,0.0} } {25}, File "Flx-2D_Sde.pos"];
      Print[Tmp,OnLine { {Rds,Hgt,0.0} {0.0,Hgt,0.0} } {25}, File "Tmp-2D_Top.pos"];
      Print[Flx,OnLine { {Rds,Hgt,0.0} {0.0,Hgt,0.0} } {25}, File "Flx-2D_Top.pos"];
    }
  }
}

/* ================================================================== */

