/* === Science & Technology Consultants (SciTeX) = Fri-03-10-3006 === */

/* --- Jacobian (Axisymmetric 2D) ----------------------------------- */

Jacobian {
  {Name JacDmn;
    Case {
      {Region Vol; Jacobian VolAxi;}
      {Region Sfc; Jacobian SurAxi;}
    }
  }
  {Name JacVol;
    Case {
      {Region Vol; Jacobian VolAxi;}
    }
  }
  {Name JacSfc;
    Case {
      {Region Sfc; Jacobian SurAxi;}
    }
  }
}

/* --- Integration -------------------------------------------------- */

Integration {
  {Name Int;
    Case {
      {Type Gauss;
        Case {
          { GeoElement Point      ; NumberOfPoints  1;}
          { GeoElement Line       ; NumberOfPoints  3;}
          { GeoElement Triangle   ; NumberOfPoints  4;}
          { GeoElement Quadrangle ; NumberOfPoints  4;}
          { GeoElement Tetrahedron; NumberOfPoints  4;}
          { GeoElement Hexahedron ; NumberOfPoints  6;}
          { GeoElement Prism      ; NumberOfPoints  6;}
        }
      }
    }
  }
}

/* --- Function Space ----------------------------------------------- */

FunctionSpace {
  {Name TmpSpc; Type Form0;
    BasisFunction {
      {Name TmpFct; NameOfCoef TmpCof; Function BF_Node; Support Dmn; Entity NodesOf[All];}
    }
    Constraint {
      {NameOfCoef TmpCof; EntityType NodesOf; NameOfConstraint TmpCon;}
    }
  }
}

/* --- Formulation -------------------------------------------------- */

Formulation {
  {Name TmpFrm; Type FemEquation;
    Quantity {
      {Name Tmp; Type Local; NameOfSpace TmpSpc;}
    }
    Equation {
      Galerkin {Dt [MasDen[{Tmp}] * HeaCap[{Tmp}] * Dof{Tmp}, {Tmp}]; 
                In Vol; Integration Int; Jacobian JacVol;}

      Galerkin {[TheCon[{Tmp}] * Dof{d Tmp}, {d Tmp}];
                In Vol; Integration Int; Jacobian JacVol;}

      Galerkin {[-HeaPwr[], {Tmp}];
                In Vol; Integration Int; Jacobian JacVol;}

      Galerkin {[-HeaFlx[], {Tmp}];
                In Sfc; Integration Int; Jacobian JacSfc;}

      Galerkin {[ HTCCvn[{Tmp}] * Dof{Tmp}, {Tmp}];
                In Sfc; Integration Int; Jacobian JacSfc;}

      Galerkin {[-HTCCvn[{Tmp}] * TmpCvn[], {Tmp}];
                In Sfc; Integration Int; Jacobian JacSfc;}

      Galerkin {[ HTCRdn[{Tmp}] * ({Tmp})^4, {Tmp}];
                In Sfc; Integration Int; Jacobian JacSfc;}

      Galerkin {[-HTCRdn[{Tmp}] * (TmpRdn[])^4, {Tmp}];
                In Sfc; Integration Int; Jacobian JacSfc;}
    }
  }
}

/* --- Resolution --------------------------------------------------- */

Resolution {
  {Name TmpResNonLin;
    System {
      {Name Tmp; NameOfFormulation TmpFrm;}
    }
    Operation {
      InitSolution Tmp;
      IterativeLoop[NonLinCnt,NonLinEps,NonLinRlx] {
        GenerateJac Tmp;
        SolveJac Tmp;
      }
      SaveSolution Tmp;
    }
  }

  {Name TmpResLin;
    System {
      {Name Tmp; NameOfFormulation TmpFrm;}
    }
    Operation {
      InitSolution Tmp;
      Generate Tmp;
      Solve Tmp;
      SaveSolution Tmp;
    }
  }

  {Name TmpResNonLinTra;
    System {
      {Name Tmp; NameOfFormulation TmpFrm;}
    }
    Operation { 
      InitSolution Tmp;
      SaveSolution Tmp;
      TimeLoopTheta {
        Time0 TmeZro; TimeMax TmeDrn; DTime TmeStp; Theta 1.0;
        Operation {
          IterativeLoop[NonLinCnt,NonLinEps,NonLinRlx] {
            GenerateJac Tmp;
            SolveJac Tmp;
          }
          Test[SveFct[]] {SaveSolution Tmp;}
        } 
      } 
    }
  }

  {Name TmpResLinTra;
    System {
      {Name Tmp; NameOfFormulation TmpFrm;}
    }
    Operation { 
      InitSolution Tmp;
      SaveSolution Tmp;
      TimeLoopTheta {
        Time0 TmeZro; TimeMax TmeDrn; DTime TmeStp; Theta 1.0;
        Operation {
          Generate Tmp;
          Solve Tmp;
          Test[SveFct[]] {SaveSolution Tmp;}
        } 
      } 
    }
  }
}

/* --- Post Processing ---------------------------------------------- */

PostProcessing {
  {Name TmpPst; NameOfFormulation TmpFrm;
    Quantity {
      {Name Tmp; Value{Local{[{Tmp}]                            ; In Dmn; Jacobian JacDmn;}}}
      {Name Flx; Value{Local{[-TheCon[{Tmp}] * {Grad Tmp}]      ; In Vol; Jacobian JacVol;}}}
      {Name Abs; Value{Local{[ TheCon[{Tmp}] * Norm[{Grad Tmp}]]; In Vol; Jacobian JacVol;}}}
    }
  }
}

/* ================================================================== */

